@@ -358,7 +358,7 @@ topicsModel <- function(
   return(model)
 }
 
-#' Predict topic distributions
+#' topicsPredict, topicsPreds, topicsAssess and topicsClassify
 #' 
 #' The function to predict the topics of a new document with the trained model.
 #' @param model (list) The trained model.
@@ -397,13 +397,13 @@ topicsModel <- function(
 #'                      num_iterations = 1000,
 #'                      seed = 42)
 #'                      
-#' preds <- topicsPreds(model = model, # output of topicsModel()
+#' preds <- topicsPredict(model = model, # output of topicsModel()
 #'                      data = dep_wor_data$Depphrase)
 #' }
 #' @importFrom tibble as_tibble tibble
 #' @importFrom dplyr %>%
 #' @export
-topicsPreds <- function(
+topicsPredict <- function(
     model, 
     data, 
     num_iterations = 200,
@@ -509,3 +509,22 @@ topicsPreds <- function(
   return(preds)
 }
 
+
+# Alias functions
+#' @rdname topicsPredict
+# @examples textAssess(model = model, data = dep_wor_data$Depphrase)
+#' @export
+topicsAssess <- topicsPredict
+
+#' @rdname topicsPredict
+# @examples textClassify(model = model, data = dep_wor_data$Depphrase)
+#' @export
+topicsClassify <- topicsPredict
+
+#' @rdname topicsPredict
+# @examples textClassify(model = model, data = dep_wor_data$Depphrase)
+#' @export
+topicsPreds <- topicsPredict
+
+
+
