@@ -29,6 +29,8 @@
 #' @param width Width of the saved scatter plot in inches. Default: 10.
 #' @param height Height of the saved scatter plot in inches. Default: 8.
 #' @param seed Seed for reproducibility, ensuring consistent plot generation. Default: 42.
+#' @param title_font Font family used for all non-word text elements in the plots (e.g., titles, axis labels, tick labels,
+#' legend text, annotations). Default: "sans". Examples: "serif", "mono", or a system-installed font family name.
 #' @importFrom ggplot2 ggplot geom_point scale_color_manual labs theme_minimal theme element_blank geom_hline geom_vline
 #' @importFrom rlang sym !!
 #' @importFrom ggforce geom_circle
@@ -57,8 +59,9 @@ topicsScatterLegend <- function(
     scatter_legend_circles_num = 4,
     width = 10, 
     height = 8, 
-    seed = 42
-    ) {
+    seed = 42,
+    title_font = "sans"
+) {
   
   # Determine x, y, and color columns
   x_column <- names(filtered_test)[5]
@@ -111,8 +114,7 @@ topicsScatterLegend <- function(
       names(backgr_dots) <- names(popout) # No background dots
     }
   }
- 
-#  if (scatter_popout_dot_size == "prevalence"){
+  
   if (max(popout$prevalence) == min(popout$prevalence)) {
     # If all prevalence values are the same, assign the midpoint size to all rows
     popout <- popout %>%
@@ -129,7 +131,7 @@ topicsScatterLegend <- function(
   
   # Update scatter_popout_dot_size after mutation
   scatter_popout_dot_size <- popout$dot_size      
-
+  
   if (max(backgr_dots$prevalence) == min(backgr_dots$prevalence)) {
     # If all prevalence values are the same, assign the midpoint size to all rows
     backgr_dots <- backgr_dots %>%
@@ -145,9 +147,7 @@ topicsScatterLegend <- function(
   }
   
   scatter_bg_dot_size <- backgr_dots$`bg_dot_size`
-      
-#  }else{scatter_popout_dot_size <- scatter_popout_dot_size}
-    
+  
   # Generate scatter plot
   plot <- generate_scatter_plot(
     popout = popout,
@@ -166,7 +166,8 @@ topicsScatterLegend <- function(
     scatter_show_axis_values = scatter_show_axis_values,
     scatter_legend_circles = scatter_legend_circles,
     scatter_legend_circles_radius = scatter_legend_circles_radius,
-    scatter_legend_circles_num = scatter_legend_circles_num
+    scatter_legend_circles_num = scatter_legend_circles_num,
+    title_font = title_font
   )
   
   # Save the plot
@@ -184,9 +185,6 @@ topicsScatterLegend <- function(
                     create.dir = TRUE)
   }
   
-  
-  #if (!only_two && !only_five){return (popout)}else{ return (NULL) }
-  
   output <- list()
   output[[1]] <- popout
   output[[2]] <- plot
@@ -195,7 +193,6 @@ topicsScatterLegend <- function(
   return(output)
 }
 
-
 #' @param filtered_test A data frame containing the input data, which must include a `color_categories` column. 
 #' This column specifies the categories used for determining pop-out topics.
 #' @param num_popout A vector of exactly 9 integers, specifying the number of topics to "pop out" for each 
@@ -339,6 +336,9 @@ determine_popout_topics <- function(
 #' @param scatter_legend_circles Plot concentric circles for the scatter legend
 #' @param scatter_legend_circles_radius Radius of first concentric circle
 #' @param scatter_legend_circles_num Number of Concentric circles
+#' @param title_font Font family used for all non-word text elements in the plots (e.g., titles, axis labels, tick labels,
+#' legend text, annotations). Default: "sans". Examples: "serif", "mono", or a system-installed font family name.
+
 #' @noRd
 generate_scatter_plot <- function(
     popout,
@@ -357,7 +357,8 @@ generate_scatter_plot <- function(
     scatter_show_axis_values,
     scatter_legend_circles = FALSE,
     scatter_legend_circles_radius = 0,
-    scatter_legend_circles_num = 4
+    scatter_legend_circles_num = 4,
+    title_font = "sans"
 ) {
   
   # Define aesthetics for popout and background points
@@ -420,17 +421,17 @@ generate_scatter_plot <- function(
                         alpha = scatter_legend_dots_alpha) +
     ggplot2::scale_color_manual(values = bivariate_color_codes) +
     ggplot2::labs(x = label_x_name, y = label_y_name, color = '') +
-    ggplot2::theme_minimal() +
+    ggplot2::theme_minimal(base_family = title_font) +
     ggplot2::theme(
       axis.text = if (scatter_show_axis_values) ggplot2::element_text(size = 12) else ggplot2::element_blank(),
       axis.ticks = if (scatter_show_axis_values) ggplot2::element_line() else ggplot2::element_blank(),
       legend.position = "none"
     )
-
+  
   
   # Add topic numbers if enabled
   if (allow_topic_num_legend) {
-    plot <- plot + geom_text(
+    plot <- plot + ggplot2::geom_text(
       data = popout, 
       ggplot2::aes(x = !!ggplot2::sym(x_col), 
                    y = if (is.null(y_col)) 1 else !!ggplot2::sym(y_col), 
@@ -471,36 +472,31 @@ generate_scatter_plot <- function(
   if (is.null(y_col)){
     plot <- plot + 
       ggplot2::theme(
-        # Then apply this hjust_value and move x axis downward
         axis.title.x = ggplot2::element_text(hjust = 0.5,
                                              margin = ggplot2::margin(t = 21.3, unit = "pt")
         ),
         axis.text.x = ggplot2::element_text(margin = ggplot2::margin(t = 21, unit = "pt"), size = 12),
         legend.position = "none",
-        # Remove all y-axis elements
         axis.title.y = ggplot2::element_blank(),
         axis.text.y = ggplot2::element_blank(),
         axis.ticks.y = ggplot2::element_blank(),
         axis.line.y = ggplot2::element_blank(),
-        axis.ticks.length.y = ggplot2::unit(0, "pt"), # Remove tick marks
+        axis.ticks.length.y = ggplot2::unit(0, "pt"),
         panel.spacing.y= ggplot2::unit(0, "lines"),
         panel.border = ggplot2::element_blank(),
         panel.grid.major.y = ggplot2::element_blank(),
         panel.grid.minor.y = ggplot2::element_blank(),
         aspect.ratio = 1/20,
-        # Other settings
         plot.margin = ggplot2::margin(0.5, 0.5, 1, 0.5, "cm") 
       ) 
   }else{
     plot <- plot +
       ggplot2::theme(
-        # Then apply this hjust_value and move x axis downward
         axis.title.x = ggplot2::element_text(hjust = 0.5,
                                              margin = ggplot2::margin(t = 10.6, unit = "pt")
         ),
         axis.text.x = ggplot2::element_text(margin = ggplot2::margin(t = 10.3, unit = "pt"), size = 12),
         legend.position = "none",
-        # Other settings
         axis.ticks.x = ggplot2::element_line(),
         axis.text.y = ggplot2::element_text(size = 12),
         plot.margin = ggplot2::margin(0.5, 0.5, 0.5, 0.5, "cm")
@@ -509,14 +505,14 @@ generate_scatter_plot <- function(
   
   #Add concentric circles 2 dimensional scatter legend plots
   if(!is.null(y_col) && scatter_legend_circles){
-
+    
     if(scatter_legend_circles_radius == 0) {
-     radius <- interval/2 
+      radius <- interval/2 
     } 
     else {
-     radius <- scatter_legend_circles_radius
+      radius <- scatter_legend_circles_radius
     }
-
+    
     x0 <- y0 <- r <- NULL
     circles <- data.frame(
       x0 = 0,
@@ -526,12 +522,14 @@ generate_scatter_plot <- function(
     plot <- plot  + ggplot2::geom_hline(yintercept = 0, size = 0.2, color = "#787373") + ggplot2::geom_vline(xintercept = 0, size = 0.2, color = "#787373")
     plot <- plot + ggforce::geom_circle(aes(x0 = x0, y0 = y0, r = r), linetype = 2, data = circles, linewidth = 0.2, color = "#787373")
   }
-
-  plot <- plot + ggplot2::coord_cartesian(clip = "off") # Prevent clipping
+  
+  plot <- plot + ggplot2::coord_cartesian(clip = "off")
   
   return(plot)
 }
 
+
+
 #### topicsGridLegend ####
 #'  Plot a grid (matrix) legend (available for the text-package)
 #' @param bivariate_color_codes A vector of color codes specifying the colors for the 3x3 grid legend.
@@ -552,6 +550,8 @@ generate_scatter_plot <- function(
 #' @param topic_data_all A data frame containing all topic data, including the `color_categories` column used for counting topics.
 #' @param legend_number_color Color of the numeric annotations in the grid legend. Must be provided by the user.
 #' @param legend_number_size Font size of the numeric annotations in the grid legend. Must be provided by the user.' @return A legend plot saved that can be combined with the plot object.
+#' @param title_font Font family used for all non-word text elements in the plots (e.g., titles, axis labels, tick labels,
+#' legend text, annotations). Default: "sans". Examples: "serif", "mono", or a system-installed font family name.
 #' @importFrom tidyr gather separate
 #' @importFrom dplyr mutate
 #' @importFrom ggplot2 geom_tile ggtitle scale_fill_identity labs theme_void annotate theme element_text coord_fixed ggsave
@@ -576,7 +576,8 @@ topicsGridLegend <- function(
     legend_y_axes_label,
     topic_data_all,
     legend_number_color,
-    legend_number_size
+    legend_number_size,
+    title_font = "sans"
 ) {
   if (y_axes_1 == 2){y_axes_1 <- ""}else{y_axes_1 <- "only_x_dimension"}
   legCor <- bivariate_color_codes
@@ -597,12 +598,10 @@ topicsGridLegend <- function(
     # Only select 3 colors
     bivariate_color_data <- bivariate_color_data[, c(4, 5, 6)]
     colnames(bivariate_color_data) <- c("1 - 2", "2 - 2", "3 - 2")
-    #bivariate_color_data
-    # Remove the y axes title on the legend
     legend_y_axes_label <- " "}
+  
   # To output the number of categories for dim 1 and dim 2 (plot 1dim or 2dim)
   if (y_axes_1 == "only_x_dimension") {
-    # for future only x dim grid in topicsTest
     categoryTotal_x_axes = c(
       sum(topic_data_all$color_categories == 1,
           na.rm = TRUE),
@@ -634,15 +633,13 @@ topicsGridLegend <- function(
       y = legend_y_axes_label
     ) +
     ggplot2::theme_void() +
-    #    ggplot2::annotate(geom="text", x=2, y=2, label="ns",
-    #               color = titles_color, size=legend_number_size)+
     {
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 1, y = 3, label = sum(topic_data_all$color_categories == 1,
                                                    na.rm = TRUE
           ),
-          color = legend_number_color, size = legend_number_size#bivariate_color_codes[1]
+          color = legend_number_color, size = legend_number_size
         )
       }
     } +
@@ -709,11 +706,12 @@ topicsGridLegend <- function(
       }
     } +
     ggplot2::theme(
-      plot.title = ggplot2::element_text(hjust = 0.5, size = legend_title_size + 1),
-      title = ggplot2::element_text(color = titles_color),
-      axis.title.x = ggplot2::element_text(color = titles_color),
-      axis.title = ggplot2::element_text(size = legend_title_size),
-      axis.title.y = ggplot2::element_text(angle = 90, color = titles_color)
+      text = ggplot2::element_text(family = title_font),
+      plot.title = ggplot2::element_text(hjust = 0.5, size = legend_title_size + 1, family = title_font),
+      title = ggplot2::element_text(color = titles_color, family = title_font),
+      axis.title.x = ggplot2::element_text(color = titles_color, family = title_font),
+      axis.title = ggplot2::element_text(size = legend_title_size, family = title_font),
+      axis.title.y = ggplot2::element_text(angle = 90, color = titles_color, family = title_font)
     ) +
     ggplot2::coord_fixed()
   
@@ -734,6 +732,7 @@ topicsGridLegend <- function(
   return(legend)
 }
 
+
 #' The function to create lda wordclouds
 #' @param model (list) The trained model
 #' @param test (list) The test results
@@ -754,6 +753,10 @@ topicsGridLegend <- function(
 #' @param height (integer) The width of the topic (units = "in").
 #' @param max_size (integer) The max size of the words.
 #' @param seed (integer) The seed to set for reproducibility
+#' @param word_font Font family used for the word text in the wordclouds (i.e., the plotted words only).
+#' Default: "sans". Examples: "serif", "mono", or a system-installed font family name (e.g., "Arial", "Times New Roman").
+#' @param title_font Font family used for all non-word text elements in the plots (e.g., titles, axis labels, tick labels,
+#' legend text, annotations). Default: "sans". Examples: "serif", "mono", or a system-installed font family name.
 #' @return nothing is returned, the wordclouds are saved in the save_dir
 #' @noRd
 topicsPlot1 <- function(
@@ -775,13 +778,14 @@ topicsPlot1 <- function(
     width = 10, 
     height = 8,
     max_size = 10, 
-    seed = 42){
+    seed = 42,
+    word_font  = "sans",
+    title_font = "sans"
+){
   
   df_list = NULL
-
+  
   if (!is.null(model)){
-    
-    
     if (model$model_type == "bert_topic") {
       
       if(!is.null(test)){
@@ -846,13 +850,14 @@ topicsPlot1 <- function(
     width = width, 
     height = height,
     max_size = max_size,
-    seed = seed)
+    seed = seed,
+    word_font = word_font,
+    title_font = title_font
+  )
   
   return(plot)
-  
 }
 
-
 #' The function sets default colors or arranges user specified colors
 #' @param color_scheme (string or vector of strings) 
 #' @return default colors or specified user colours in the right order and structure.
@@ -934,8 +939,8 @@ colour_settings <- function(
     if (dim == 1 && !is.null(ngrams)){
       # gradient pairs
       bivariate_color_codes <- c(
-        "#EAEAEA", "darkred", # negative ngrams colours
-        "#EAEAEA", "darkgreen" # positve ngrams colours
+        "#d0d0d0", "#ff7c00", # negative ngrams colours (Orange)
+        "#d0d0d0", "#00508c"  # positve ngrams colours (Blue)
       )
     }
     
@@ -944,31 +949,31 @@ colour_settings <- function(
     if (dim == 1 && is.null(ngrams)){
       # gradient pairs
       
-      # Colors for the "background" words
+      # Colors for the "background" words (The "Low" value)
       bivariate_color_codes_b <- c(
-        "#e07f6a",  "lightgray","#5dc688"
+        "#d0d0d0",  "#d0d0d0","#d0d0d0"
       )
-      # Colors for the "front" words
+      # Colors for the "front" words (The "High" value)
       bivariate_color_codes_f <- c(
-        "darkred", "darkgray", "darkgreen"
-      ) 
+        "#ff7c00", "#a4a4a4", "#00508c" # Orange, Gray, Blue
+      )
     }
     
     if (dim == 2){
       # Colors for the "background" words
-      bivariate_color_codes_b <- rep("lightgray", 9)
+      bivariate_color_codes_b <- rep("#d0d0d0", 9)
       
       # Colors for the "front" words 
       bivariate_color_codes_f <-  c(
-        "#398CF9",  # quadrant 1 (upper left corner)
-        "#60A1F7",  # quadrant 2 
-        "#5dc688",  # quadrant 3 (upper right corner)
-        "#e07f6a",  # quadrant 4
-        "darkgray", # quadrant 5 (middle square)
-        "#40DD52",  # quadrant 6 
-        "#FF0000",  # quadrant 7 (bottom left corner)
-        "#EA7467",  # quadrant 8 
-        "#85DB8E")  # quadrant 9 (bottom right corner)
+        "#00508c",  # quadrant 1 (upper left corner)
+        "#635089",  # quadrant 2 
+        "#A64E85",  # quadrant 3 (upper right corner)
+        "#00807d",  # quadrant 4
+        "#a4a4a4",  # quadrant 5 (middle square)
+        "#bf6f51",  # quadrant 6 
+        "#009E73",  # quadrant 7 (bottom left corner)
+        "#8a9f2e",  # quadrant 8 
+        "#E69F00")  # quadrant 9 (bottom right corner)
     }
   }
   
@@ -1023,6 +1028,112 @@ clean_characters_for_plotting_test <- function(test) {
 }
 
 
+#' Combine topics and distribution legend (experimental)
+#'
+#' @param plot_list (list) Output from the topicsPlot function.   
+#' @param overview_plot_type  (character) Number of dimensions to plot (1 or 2).
+#' @param title_font Font family used for all non-word text elements in the plots (e.g., titles, axis labels, tick labels,
+#' legend text, annotations). Default: "sans". Examples: "serif", "mono", or a system-installed font family name.
+#' @return An overview plot including topics and distribution legend
+#' @importFrom  ggplot2 labs element_blank theme margin element_text
+#' @importFrom patchwork wrap_plots plot_layout
+#' @export
+topicsPlotOverview <- function(
+    plot_list, 
+    overview_plot_type,
+    title_font = "sans"
+) {
+  
+  # Helper: Handles NULL, Lists of plots, and Single plots
+  get_plot_or_spacer <- function(plot_obj) {
+    if (is.null(plot_obj) || length(plot_obj) == 0) {
+      return(patchwork::plot_spacer())
+    }
+    
+    # If it's a list (like square1), take first. If it's a ggplot, take it.
+    if (is.list(plot_obj) && !ggplot2::is.ggplot(plot_obj)) {
+      p <- plot_obj[[1]]
+    } else {
+      p <- plot_obj
+    }
+    
+    return(
+      p +
+        ggplot2::theme_void() + 
+        ggplot2::labs(x = NULL, y = NULL) + 
+        ggplot2::theme(
+          text = ggplot2::element_text(family = title_font),
+          plot.margin = ggplot2::margin(2, 2, 2, 2)
+        )
+    )
+  } 
+  
+  # N-grams
+  if (overview_plot_type == "ngrams_grid") {
+    p_pos <- get_plot_or_spacer(plot_list$positive_association)
+    p_neg <- get_plot_or_spacer(plot_list$negative_association)
+    
+    combined <- (p_neg  | p_pos) + 
+      patchwork::plot_layout(guides = 'collect')
+  }
+  
+  # Selected topics Grid Version (Rows of 4) ---
+  if (overview_plot_type == "topics_grid" | overview_plot_type == "textTopics") {
+    cleaned_plots <- lapply(plot_list, get_plot_or_spacer)
+    
+    combined <- patchwork::wrap_plots(cleaned_plots, ncol = 4) + 
+      patchwork::plot_layout(guides = 'collect') &
+      ggplot2::theme(
+        text = ggplot2::element_text(family = title_font),
+        plot.margin = ggplot2::margin(5, 5, 5, 5)
+      )
+  }
+  
+  # One-dimensional topic plot
+  if (overview_plot_type == "one_dimension_topics") {
+    p1 <- get_plot_or_spacer(plot_list$square1)
+    p2 <- get_plot_or_spacer(plot_list$square2)
+    p3 <- get_plot_or_spacer(plot_list$square3)
+    
+    top_row <- (p1 | p2 | p3)
+    combined <- patchwork::wrap_plots(top_row, plot_list$distribution, ncol = 1) + 
+      patchwork::plot_layout(heights = c(1, 1)) &
+      ggplot2::theme(text = ggplot2::element_text(family = title_font))
+  }
+  
+  # Two-dimensional topic plot
+  if (overview_plot_type == "two_dimension_topics") {
+    p1 <- get_plot_or_spacer(plot_list$square1)
+    p2 <- get_plot_or_spacer(plot_list$square2)
+    p3 <- get_plot_or_spacer(plot_list$square3)
+    p4 <- get_plot_or_spacer(plot_list$square4)
+    p6 <- get_plot_or_spacer(plot_list$square6)
+    p7 <- get_plot_or_spacer(plot_list$square7)
+    p8 <- get_plot_or_spacer(plot_list$square8)
+    p9 <- get_plot_or_spacer(plot_list$square9)
+    
+    dist_plot <- plot_list$distribution + 
+      ggplot2::theme(
+        text = ggplot2::element_text(family = title_font),
+        plot.margin = ggplot2::margin(5, 5, 5, 5)
+      )
+    
+    combined <- (p1 | p2 | p3) /
+      (p4 | dist_plot | p6) /
+      (p7 | p8 | p9) +
+      patchwork::plot_layout(guides = 'collect') & 
+      ggplot2::theme(
+        text = ggplot2::element_text(family = title_font),
+        plot.margin = ggplot2::margin(0, 0, 0, 0),
+        axis.title = ggplot2::element_blank()
+      )
+  }
+  
+  return(combined)
+}
+
+#plotout <- create_overview_plot(plot_list)
+
 #' Plot word clouds
 #' 
 #' This function create word clouds and topic figures
@@ -1085,6 +1196,11 @@ clean_characters_for_plotting_test <- function(test) {
 #'   "lightgray", "#85DB8E")     # quadrant 9 (bottom right corner).
 #'
 #' 
+#' @param word_font Font family used for the word text in the wordclouds (i.e., the plotted words only).
+#' Default: "sans". Examples: "serif", "mono", or a system-installed font family name (e.g., "Arial", "Times New Roman").
+#' @param title_font Font family used for all non-word text elements in the plots (e.g., titles, axis labels, tick labels,
+#' legend text, annotations). Default: "sans". Examples: "serif", "mono", or a system-installed font family name.
+#' @param overview_plot (boolean) Whether to produce an overview plot, including some of the topics and the ditribution (experimental).
 #' @param highlight_topic_words (str vector) Words to highlight in topics (e.g., negative words). Format: highlight_topic_words = c("not", "never"). The default value is NULL.
 #' @param allowed_word_overlap (numeric) A filter function determining the maximum number of identical words in the topics to be plotted. 
 #' This filter removes topics within each "color group" and also include removing topics from the distribution and grid legends; 
@@ -1135,8 +1251,11 @@ topicsPlot <- function(
     p_alpha = 0.05,
     p_adjust_method = "none",
     ngrams_max = 30,
-    ngram_select = "prevalence",
+    ngram_select = "estimate",
     color_scheme = "default",
+    word_font  = "sans",
+    title_font = "sans",
+    overview_plot = TRUE,
     highlight_topic_words = NULL,
     scale_size = FALSE,
     plot_topics_idx = NULL,
@@ -1166,29 +1285,48 @@ topicsPlot <- function(
     grid_legend_x_axes_label = "legend_x_axes_label",
     grid_legend_y_axes_label = "legend_y_axes_label",
     grid_legend_number_color = 'white',
-    grid_legend_number_size = 15){
-  
+    grid_legend_number_size = 15
+){
   
   set.seed(seed)
   
   #### Setting the number of dimensions to plot ####
-  # If no test is provide set dim to 0 
   if(is.null(test)){
     dim = 0
   }
   
-  # If a test is given
   if(!is.null(test)){
-    
-    # set default to 1 since that works for both n-grams and topics
     dim = 1
-    
-    # Only set dim to 2 if the test include enough tests
     if(ncol(test$test) == 12) {
       dim = 2
     }
   }
   
+  #### Setting type of overview plot ####
+  if(overview_plot) {
+    if(!is.null(test)) {
+      overview_type = "one_dimension_topics"
+      if(ncol(test$test) == 12) {
+        overview_type = "two_dimension_topics"
+      }
+    }
+    
+    if(!is.null(plot_topics_idx) ){
+      if(plot_topics_idx[[1]] == "textTopics"){
+        overview_type = "textTopics"
+        plot_topics_idx = NULL
+      }
+    }
+    
+    if(!is.null(plot_topics_idx) | !is.null(plot_n_most_prevalent_topics)) {
+      overview_type = "topics_grid"
+    }
+    
+    if(!is.null(ngrams)) {
+      overview_type = "ngrams_grid"
+    }
+  }
+  
   #### Setting colors ####
   codes <- colour_settings(
     color_scheme = color_scheme, 
@@ -1200,9 +1338,9 @@ topicsPlot <- function(
   bivariate_color_codes   <- codes[[1]]
   bivariate_color_codes_b <- codes[[2]]
   bivariate_color_codes_f <- codes[[3]]
-
+  
   if (!is.null(bivariate_color_codes_f)){
-      names(bivariate_color_codes_f) <- as.character(seq(1:length(bivariate_color_codes_f))) # The names of the color vector prevent the wrong ordering of colors in scatter plot.
+    names(bivariate_color_codes_f) <- as.character(seq(1:length(bivariate_color_codes_f)))
   }
   
   #### Controlling parameter settings and giving instructions #####
@@ -1214,57 +1352,37 @@ topicsPlot <- function(
   
   #### Add adjustment of p-values for multiple comparisons ####
   if (p_adjust_method != "none"){
-    
-    # reset the adjusted p-value with potentially new correction method
     test$test[[8]]<- stats::p.adjust(p = test$test[[7]],
-                              method = p_adjust_method)
+                                     method = p_adjust_method)
     
     if(dim == 2) test$test[[12]]<- stats::p.adjust(p = test$test[[11]],
-                                            method = p_adjust_method)
-    
+                                                   method = p_adjust_method)
   } 
-  if(p_adjust_method != "none"){
-    
-    # set the original p-value as the adjusted for plotting
+  
+  if(p_adjust_method == "none"){
     test$test[[8]] <- test$test[[7]]
     if(dim == 2) test$test[[12]] <- test$test[[11]]
   }
   
   #### Setting colour-categories: Selecting elements to plot according to the p_alpha ####
   if (dim == 1) {
-    
-    # Getting column names
     bak1 <- colnames(test$test)[c(5,8)]
     colnames(test$test)[c(5,8)] <- c('x_plotted', 'adjusted_p_values.x')
-    
-    # Getting colour-categories
     test$test <- topicsNumAssign_dim2(test$test, p_alpha, 1)
-    # Setting the original clumns
     colnames(test$test)[c(5,8)] <- bak1
-    
   }
   if (dim == 2){
-    
     bak1 <- colnames(test$test)[c(5,8,9,12)]
     colnames(test$test)[c(5,8,9,12)] <- c('x_plotted', 'adjusted_p_values.x',
                                           'y_plotted', 'adjusted_p_values.y')
-    
     test$test <- topicsNumAssign_dim2(test$test, p_alpha, 2)
     colnames(test$test)[c(5,8,9,12)] <- bak1
   }
   
-  
   #### Filtering duplicate topics #### 
   if (!is.null(allowed_word_overlap) & is.null(plot_n_most_prevalent_topics)){
-    
-    # Remove duplicates within group categories
     arranged_topics <- test$test 
     max_n_texts <- nrow(test$test )
-
-    # Apply the function to each color group based on scatter_legend_n
-    #df = arranged_topics
-    
-    # Store the original column names
     original_col_order <- names(arranged_topics)
     
     test$test <- arranged_topics %>%
@@ -1276,8 +1394,8 @@ topicsPlot <- function(
         n_texts = max_n_texts, 
         allowed_word_overlap)) %>%
       dplyr::ungroup() %>%
-      dplyr::select(-color_categories1) %>%            # Remove the temporary column
-      dplyr::select(dplyr::all_of(original_col_order)) # Reorder columns to the original order
+      dplyr::select(-color_categories1) %>%
+      dplyr::select(dplyr::all_of(original_col_order))
   }
   
   #### Selecting the most prevalence topics ####
@@ -1286,26 +1404,20 @@ topicsPlot <- function(
   }
   
   if (!is.null(plot_n_most_prevalent_topics)) {
-    
     arranged_topics <- model$summary %>% 
       dplyr::arrange(dplyr::desc(prevalence))
     
-    #if(!is.null(allowed_word_overlap)){
     arranged_topics <- select_non_overlapping_texts(
-        arranged_topics, 
-        "top_terms", 
-        n_texts = plot_n_most_prevalent_topics, 
-        allowed_word_overlap = allowed_word_overlap 
-      )
-   # }
+      arranged_topics, 
+      "top_terms", 
+      n_texts = plot_n_most_prevalent_topics, 
+      allowed_word_overlap = allowed_word_overlap 
+    )
     
     plot_topics_idx <- arranged_topics$topic
-    
   }
   
-  
-  #### NGRAM filtering and fixing tags (e.g., <place>) in ngrams because of error when plotting #### 
-  
+  #### NGRAM filtering and fixing tags (e.g., <place>) #### 
   if(!is.null(ngrams) & !is.null(ngrams_max)){
     
     if(is.null(test)){
@@ -1329,17 +1441,14 @@ topicsPlot <- function(
       
       ngrams <- clean_characters_for_plotting_grams(ngrams)
     }
+    
     if(!is.null(test)){
-      
       if (!ngram_select %in% c("prevalence", "estimate")){
         stop("ngram_select incorrect -- when using ngram and test use one of prevalence or estimate")
       }
       
-      # merge frequency
-      # get the name of the column to arrange after colnames(test$test)
       beta_column <- names(test$test)[grepl("_beta$", names(test$test))][1]
-    
-      # Filter and arrange by positive beta scores
+      
       positive_ngrams <- test$test %>%
         dplyr::filter(.data[[beta_column]] > 0) %>%
         {
@@ -1357,7 +1466,8 @@ topicsPlot <- function(
         dplyr::filter(.data[[beta_column]] < 0) %>%
         {
           if (ngram_select == "estimate") {
-            dplyr::arrange(., dplyr::desc(.data[[beta_column]]))
+            #dplyr::arrange(., dplyr::desc(.data[[beta_column]]))
+            dplyr::arrange(., .data[[beta_column]])
           } else if (ngram_select == "prevalence") {
             dplyr::arrange(., dplyr::desc(prevalence))
           } else {
@@ -1365,23 +1475,18 @@ topicsPlot <- function(
           }
         } %>%
         dplyr::slice_head(n = ngrams_max)
-      negative_ngrams[34,]
-      # Combine the positive and negative n-grams
+      
+      
       test$test <- dplyr::bind_rows(positive_ngrams, negative_ngrams)
-
       test <- clean_characters_for_plotting_test(test)
     }
   }
   
   #### Making the plots ####
-  #### Plotting topics from model without at test | ####
-  #### Plotting n-grams WIHT test | ### 
-  #### Plotting n-grams WIHTOUT test | ####
   if(!is.null(model) & is.null(test) | 
      !is.null(ngrams) && !is.null(test)|
      !is.null(ngrams) && is.null(test)){
     
-    
     plot_list <- topicsPlot1(
       model = model,
       ngrams = ngrams,
@@ -1392,7 +1497,7 @@ topicsPlot <- function(
       plot_topics_idx = plot_topics_idx,
       popout = NULL,
       color_negative_cor = ggplot2::scale_color_gradient(
-        low = bivariate_color_codes[1], high = bivariate_color_codes[2]), # grey in hex code
+        low = bivariate_color_codes[1], high = bivariate_color_codes[2]),
       color_positive_cor = ggplot2::scale_color_gradient(
         low = bivariate_color_codes[3], high = bivariate_color_codes[4]),
       save_dir = save_dir,
@@ -1400,16 +1505,14 @@ topicsPlot <- function(
       width = width, 
       height = height,
       max_size = max_size, 
-      seed = seed
+      seed = seed,
+      word_font = word_font,
+      title_font = title_font
     )
   }
   
-  
   #### 1- or 2 dimensional topic-plots ####
-
-  
   if(is.null(ngrams) & !is.null(test$test)){
-    
     popout1 <- topicsScatterLegend(
       bivariate_color_codes = bivariate_color_codes_f,
       filtered_test = test$test,
@@ -1433,13 +1536,12 @@ topicsPlot <- function(
       figure_format = figure_format,
       width = 15,
       height = 15*9/16,
-      seed = seed
+      seed = seed,
+      title_font = title_font
     )
     popout <- popout1$popout
   }
   
-  
-  
   if (!is.null(model) & !is.null(test)){
     
     if (dim == 1){
@@ -1477,7 +1579,9 @@ topicsPlot <- function(
           width = width, 
           height = height,
           max_size = max_size, 
-          seed = seed
+          seed = seed,
+          word_font = word_font,
+          title_font = title_font
         )
         plot_list[[i]] <- plot
       }
@@ -1514,7 +1618,9 @@ topicsPlot <- function(
           width = width, 
           height = height,
           max_size = max_size, 
-          seed = seed
+          seed = seed,
+          word_font = word_font,
+          title_font = title_font
         )
         plot_list[[k]] <- plot
       }
@@ -1535,11 +1641,23 @@ topicsPlot <- function(
       legend_y_axes_label = grid_legend_y_axes_label,
       topic_data_all = test[["test"]],
       legend_number_color = grid_legend_number_color,
-      legend_number_size = grid_legend_number_size
+      legend_number_size = grid_legend_number_size,
+      title_font = title_font
     )
     
     plot_list[["legend"]] <- legend
     plot_list[["distribution"]] <- popout1$legend
   }
+  
+  # Create overview image
+  if(overview_plot){
+    overview_p <- topicsPlotOverview(
+      plot_list = plot_list, 
+      overview_plot_type = overview_type,
+      title_font = title_font
+    )
+    plot_list[["overview_plot"]] <- overview_p
+  }
+  
   return(plot_list)
-}
+}
\ No newline at end of file
